package Yahoo::Marketing::APT::TargetingDictionaryService;
# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.
# The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997)

use strict; use warnings;

use base qw/Yahoo::Marketing::APT::Service/;



1;

