package Yahoo::Marketing::APT::LocationService;
# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.
# The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997)

use strict; use warnings;

use base qw/Yahoo::Marketing::APT::Service/;


=head1 NAME

Yahoo::Marketing::APT::LocationService - an object that provides an operation that returns the URL prefix for the colocation of your account. 

This module is also used internally by other services to get the correct EWS endpoint

=cut

=head1 SYNOPSIS


See EWS documentation online for available SOAP methods:

http://help.yahoo.com/l/us/yahoo/apt/webservices/reference/services/

Also see perldoc Yahoo::Marketing::Service for functionality common to all service modules.




=head2 new

Creates a new instance

=cut


1;
