#!perl -T
# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
# The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 

use strict; use warnings;

use lib 't/lib';
use Yahoo::Marketing::APT::Test::AudienceSharingRule;

# run all the test methods in Example::Test
Test::Class->runtests;

